==> ZenTaoPMS.biz7.0.php7.0.zip: zentaopms/extension/biz/sso/ext/model/class/bizext.class.php <==
<?php //0067d
if(!extension_loaded('ionCube Loader')){$__oc=strtolower(substr(php_uname(),0,3));$__ln='ioncube_loader_'.$__oc.'_'.substr(phpversion(),0,3).(($__oc=='win')?'.dll':'.so');if(function_exists('dl')){@dl($__ln);}if(function_exists('_il_exec')){return _il_exec();}$__ln='/ioncube/'.$__ln;$__oid=$__id=realpath(ini_get('extension_dir'));$__here=dirname(__FILE__);if(strlen($__id)>1&&$__id[1]==':'){$__id=str_replace('\\','/',substr($__id,2));$__here=str_replace('\\','/',substr($__here,2));}$__rd=str_repeat('/..',substr_count($__id,'/')).$__here.'/';$__i=strlen($__rd);while($__i--){if($__rd[$__i]=='/'){$__lp=substr($__rd,0,$__i).$__ln;if(file_exists($__oid.$__lp)){$__ln=$__lp;break;}}}if(function_exists('dl')){@dl($__ln);}}else{die('The file '.__FILE__." is corrupted.\n");}if(function_exists('_il_exec')){return _il_exec();}
$documentRoot = isset($_SERVER['SCRIPT_FILENAME']) ? dirname($_SERVER['SCRIPT_FILENAME']) : $_SERVER['DOCUMENT_ROOT'];
$link = is_file($documentRoot . '/loader-wizard.php') ? '/loader-wizard.php' : 'http://www.ioncube.com/lw/';
echo "<html>
  <head>
    <meta http-equiv='content-type' content='text/html; charset=utf-8' />
    <title>error</title>
  </head>
  <body>
    <h2 style='color:red;text-align:center'>未安装 ioncube loader</h2>
    <p>您需要安装ioncube loader才能使用该功能， 使用<a href='$link'>ioncube loader安装向导</a>。</p>
    <br /><br /><br />
    <h2 style='color:red;text-align:center'>Ioncube loader doesn't installed.</h2>
    <p>You haven't installed ioncube loader extension, please visit <a href='$link'>the install wizard</a> to install it.</p>
  </body>
</html>";
exit;

?>
HR+cPrEVQjiGP6yTMIl/GlWAKA0agJOSP223uEz8rzhudGGr301SaPC51CzDxYb8lr0rMCIGnw26
i72+iGbTKWdccKK3MBmKR7hAO7z9S7VlLRlGyusUmDrM+XkLEjhO0v5odt33xpNaTHUPXVQb5CqM
Ua45B9lpD+NxMDgvfiRp3xWKssnqakZqUStzQ622KLnAi7EIBE9vRW+StR6DukwFgA2jVr0Mg4w9
wpNPOLOMQ77giILzyLV3ht3LoNlgqAn0Tqc3EYoAi0DhBBxrWlkrz8wCm5ZK5n3aCh9dOGAHYiJB
th+m28Cu1CYDKHahNV2AjTiXMc9lBKva7fcA41J9IAju8kV7dqdLEsQDGWWuNLlEcmAAQ5KzW7QC
nD/E6viapqAi+XbmpW2nu9CmkVkdGQ3TsD2md3HJ8Iusa6OJDxyzOKQr7NExwrbYZwbM4EpKmld4
BBsQnt1EHlAjkjqRwXqrw/hc9euKrnFQlPqkGZj5ZX0nP97rEcTxcMF9VY0j4mgxRWqMzKXC1egT
OIjDiMc9mB7uqHXZti64vadeVkRtFIS1Mb9QVsud3wzDcKQMbGyLpDGZGwpBkJ4W7FlNMvrUuZct
pFGBnaZb/CElLVsoxmXb3FKTUUYHOGS+iFoljOOx5DnXOOEgkzd/w2LYHKc+PRf5oojF3pqktTA/
itrkhTWu5sQ+y5/27uujyvRlAYFIfEgNv89VL027Sr0BhIneM9xZOkClQ/goL7ZAum==

==> ZenTaoPMS.biz7.3.php5.4_5.6.zip: zentaopms/extension/biz/sso/ext/model/class/bizext.class.php <==
<?php //0067d
if(!extension_loaded('ionCube Loader')){$__oc=strtolower(substr(php_uname(),0,3));$__ln='ioncube_loader_'.$__oc.'_'.substr(phpversion(),0,3).(($__oc=='win')?'.dll':'.so');if(function_exists('dl')){@dl($__ln);}if(function_exists('_il_exec')){return _il_exec();}$__ln='/ioncube/'.$__ln;$__oid=$__id=realpath(ini_get('extension_dir'));$__here=dirname(__FILE__);if(strlen($__id)>1&&$__id[1]==':'){$__id=str_replace('\\','/',substr($__id,2));$__here=str_replace('\\','/',substr($__here,2));}$__rd=str_repeat('/..',substr_count($__id,'/')).$__here.'/';$__i=strlen($__rd);while($__i--){if($__rd[$__i]=='/'){$__lp=substr($__rd,0,$__i).$__ln;if(file_exists($__oid.$__lp)){$__ln=$__lp;break;}}}if(function_exists('dl')){@dl($__ln);}}else{die('The file '.__FILE__." is corrupted.\n");}if(function_exists('_il_exec')){return _il_exec();}
$documentRoot = isset($_SERVER['SCRIPT_FILENAME']) ? dirname($_SERVER['SCRIPT_FILENAME']) : $_SERVER['DOCUMENT_ROOT'];
$link = is_file($documentRoot . '/loader-wizard.php') ? '/loader-wizard.php' : 'http://www.ioncube.com/lw/';
echo "<html>
  <head>
    <meta http-equiv='content-type' content='text/html; charset=utf-8' />
    <title>error</title>
  </head>
  <body>
    <h2 style='color:red;text-align:center'>未安装 ioncube loader</h2>
    <p>您需要安装ioncube loader才能使用该功能， 使用<a href='$link'>ioncube loader安装向导</a>。</p>
    <br /><br /><br />
    <h2 style='color:red;text-align:center'>Ioncube loader doesn't installed.</h2>
    <p>You haven't installed ioncube loader extension, please visit <a href='$link'>the install wizard</a> to install it.</p>
  </body>
</html>";
exit;

?>
HR+cP/pHZfgzFdFT06KRkHbZdqBzf1iPAQBpT6f3qUibl+N3V3ZKn+XTn3wifMEECULLIt0S7UHs
htIWl16qc/KpJNr9paAT25j26QREjs4Byou7lw/hwmutybJdQK5gB/qV9ud850SLFZamv1FdXcZm
x6H8oW+bsi3Zu47c3TG4t0Bd3kL47p1o2qvq8ET5y3H3LMMuyKEEb72G38zll11amZ1z59JCmIJy
kqDvTg74BXLvPk/D6XVz6NHSdVaUVLKleYhN6Pw0qfPlcQHpuGZwB4AYZ9NmNuNdvVoSv0o2rwTg
T/a/lRSEowz3xZxITJ8NDb8jyssfUB/3W0BfZ7g07Rt6ezjoXWQIn6EZUnuLDTQ944lxXV+98OQq
gGqY08qNNXaz1uoQL8CwYxt46mf8QdtKguP5xjLY5nJZgneMyLE4sm/niVrQHaElSz9PMUh4hEF/
uTfzVqCtWFy8y4mWNE8W50xxoaiYCp/E5KAIgYJMWbfRRiQNiF+e9IcF
